@@ -21,7 +21,7 @@ end
 module Racc
   class ParseError < StandardError; end
 end
-unless defined? ::ParseError then
+unless defined? ParseError then
   ParseError = Racc::ParseError
 end
 
