@@ -215,6 +215,13 @@ class ReturnPathHeaderTester < RUNIT::TestCase
     # missing '<' '>'
     h = TMail::HeaderField.new('Return-Path', 'xxxx@yyyy')
     assert_equal 'xxxx@yyyy', h.spec
+
+    h = TMail::HeaderField.new('Return-Path', '<>')
+    assert_instance_of TMail::Address, h.addr
+    assert_nil h.addr.local
+    assert_nil h.addr.domain
+    assert_nil h.addr.spec
+    assert_nil h.spec
   end
 
   def test_to_s
@@ -227,6 +234,10 @@ class ReturnPathHeaderTester < RUNIT::TestCase
     h = TMail::HeaderField.new('Return-Path', body)
     assert_equal '<aamine@loveruby.net>', h.to_s
     assert_equal h.to_s, h.decoded
+
+    body = '<>'
+    h = TMail::HeaderField.new('Return-Path', body)
+    assert_equal '<>', h.to_s
   end
 
 end
